/*
 *@ name:   多玩全站公共导航栏
 *@ author: 林植强
 *@ modify: David (liudawei@yy.com)
 *@ update: 2015-04-24 09:45:46
 */

(function() {

	if (/Android|webOS|iPhone|Windows Phone|iPod|BlackBerry|SymbianOS/i.test(window.navigator.userAgent) && !/[\?&]pc(?:[=&].*|$)/.test(window.location.href)) {
		var matched = window.location.href.match(/(.+\.duowan)\.com(\/\d{4}\/\d+\.html)/);
		if (matched) {
			window.location.href = matched[1] + ".cn" + matched[2];
			return;
		}
	}

	if (window.Navbar) return;

	var browser = (function(ua) {
		ua = ua.toLowerCase();

		var match = /(webkit)[ \/]([\w.]+)/.exec( ua ) || /(opera)(?:.*version)?[ \/]([\w.]+)/.exec( ua ) || /(msie) ([\w.]+)/.exec( ua ) || !/compatible/.test( ua ) && /(mozilla)(?:.*? rv:([\w.]+))?/.exec( ua ) || [],
			bn = match[1],
			b = {};

		if (bn) {
			b[bn] = match[2] || "0";
		}
		return b;
	})(navigator.userAgent);

	try { document.execCommand("BackgroundImageCache", false, true); } catch(ex) {}

	var Util = {

		isFunction: function(obj) {
			return Object.prototype.toString.call(obj) === "[object Function]";
		},

		_regExpTrim: /^(\s|\u00A0)+|(\s|\u00A0)+$/g,
		trim: function(text) {
			return (text || "").replace(Util._regExpTrim, "");
		},

		each: function(obj, callback) {
			var name, i = 0, length = obj.length,
			isObj = length === undefined || Util.isFunction(obj),
			thisp = arguments[2];
			if (thisp === undefined) {
				thisp = window;
			}
			if (isObj) {
				for (name in obj) {
					if (callback.call(thisp, obj[name], name, obj) === false) {
						break;
					}
				}
			} else {
				while(i < length && callback.call(thisp, obj[i], i, obj) !== false) {
					i++;
				}
			}
		},

		createStyleSheet: function(cssText) {
			var stylesheet;
			if (document.createStyleSheet) {
				stylesheet = document.createStyleSheet();
				stylesheet.cssText = cssText;
			} else {
				stylesheet = document.createElement("style");
				stylesheet.appendChild(document.createTextNode(cssText));
				document.getElementsByTagName("head")[0].appendChild(stylesheet);
			}
			return stylesheet;
		},

		getScript: function(url, callback) {
			var head = document.getElementsByTagName("head")[0] || document.documentElement;
			var script = document.createElement("script");
			script.type = "text/javascript";
			script.async = true;
			script.charset = "utf-8";
			script.src = url;
			script.onload = script.onreadystatechange = function() {
				if (!script.readyState || /loaded|complete/.test(script.readyState)) {
					if (Util.isFunction(callback)) {
						callback();
					}
					script.onload = script.onreadystatechange = null;
					if (script.parentNode) {
						script.parentNode.removeChild(script);
					}
				}
			};
			head.insertBefore(script, null);
		}
	};

	var Dom = {
		get: function(el) {
			var id, nodes, i, len;

			if (el) {
				if (el.nodeType) { // Node, or NodeList
					return el;
				}
				if (typeof el === "string") { // id
					id = el;
					el = document.getElementById(el);
					if (el && el.id === id) { // IE: avoid false match on "name" attribute
						return el;
					} else if (el && document.all) { // filter by name
						el = null;
						nodes = document.all[id];
						for (i = 0, len = nodes.length; i < len; ++i) {
							if (nodes[i].id === id) {
								return nodes[i];
							}
						}
					}
					return el;
				}
				return el; // some other object, just pass it back
			}

			return null;
		},

		_regExpClass: /[\n\t]/g,

		hasClass: function(el, className) {
			el = Dom.get(el);
			className = " " + className + " ";
			if ((" " + el.className + " ").replace(Dom._regExpClass, " ").indexOf(className) > -1) {
				return true;
			}
			return false;
		},

		addClass: function(el, className) {
			el = Dom.get(el);
			if (!el.className) {
				el.className = className;
			} else if (!Dom.hasClass(el, className)) {
				className = el.className + " " + className;
				el.className = Util.trim(className);
			}
		},

		removeClass: function(el, className) {
			el = Dom.get(el);
			if (el.className) {
				var s = " " + el.className.replace(Dom._regExpClass, " ") + " ";
				s = s.replace(" " + className + " ", " ");
				el.className = Util.trim(s);
			}
		},

		isAncestor: function(haystack, needle) {
			if (haystack && needle) {
				if (haystack.contains && haystack !== needle) {
					return haystack.contains(needle);
				} else if (haystack.compareDocumentPosition) {
					return !!(haystack.compareDocumentPosition(needle) & 16);
				}
			}
			return false;
		},

		getChildren: function(el) {
			el = Dom.get(el);
			var children = [];
			Util.each(el.childNodes, function(node) {
				if (node.nodeType == 1) {
					children.push(node);
				}
			});
			return children;
		}
	};

	var Event = {

		attach: function(el, name, listener) {
			el = Dom.get(el);
			if (!el) return;

			if (el.addEventListener) {
				el.addEventListener(name, listener, false);
			} else {
				el.attachEvent("on" + name, listener);
			}
		},

		preventDefault: function(e) {
			if (e.preventDefault) {
				e.preventDefault();
			} else {
				e.returnValue = false;
			}
		},

		_withinElement: function(e, el) {
			e = e || window.event;
			var relTarget = e.relatedTarget || e.fromElement;
			if (relTarget && relTarget == el || Dom.isAncestor(el, relTarget)) {
				return true;
			} else {
				return false;
			}
		},

		mouseenter: function(el, listener) {
			el = Dom.get(el);
			if (!el) return;

			if (typeof el.onmouseenter == "undefined") {
				Event.attach(el, "mouseover", function(e) {
					if (!Event._withinElement(e, el)) {
						listener(e);
					}
				});
			} else {
				Event.attach(el, "mouseenter", listener);
			}
		},

		mouseleave: function(el, listener) {
			el = Dom.get(el);
			if (!el) return;

			if (typeof el.onmouseleave == "undefined") {
				Event.attach(el, "mouseout", function(e) {
					if (!Event._withinElement(e, el)) {
						listener(e);
					}
				});
			} else {
				Event.attach(el, "mouseleave", listener);
			}
		}
	};

	function hashElements(root, hashObj) {
		var els = root.getElementsByTagName("*"), el, key;
		for (var i = 0, len = els.length; i < len; i++) {
			el = els[i];
			if (typeof el.getAttribute != "undefined" && (key = el.getAttribute("data-dom"))) {
				hashObj[key] = el;
				el.removeAttribute("data-dom");
			}
		}
	}

	var username,
		pwd,
		CSS_TEXT = '#dw-topbar .dw-topbar-logo,#dw-topbar .dw-topbar-homepage,#dw-topbar .dw-topbar-link,#dw-topbar .dw-topbar-nav,#dw-topbar .dw-topbar-login,#dw-topbar .dw-topbar-register,#dw-topbar .dw-topbar-username,#dw-topbar .dw-topbar-yuanbao,#dw-topbar .dw-topbar-logout,#dw-topbar .dw-topbar-download{float:left;_display:inline}#dw-topbar .dw-topbar-userinfo{float:right;_display:inline}html body{padding-top:36px;_padding-top:0}#dw-topbar{color:#333;width:100%;min-width:1000px;position:fixed;top:0;left:0;_position:relative;z-index:20000;height:36px;background:#e8e8e8 url(http://assets.dwstatic.com/project/topbar/img/bg_topbar.png) repeat-x 0 0}#dw-topbar *{margin:0;padding:0;font-style:normal;border:0 none;text-decoration:none;list-style-type:none;background:none;width:auto;font:12px/1.5 tahoma,"Microsoft YaHei"}#dw-topbar a{color:#333}#dw-topbar a:hover{text-decoration:underline}#dw-topbar .dw-topbar-bd{width:1000px;margin:auto;height:35px;position:relative;*zoom:1}#dw-topbar .dw-topbar-bd:before,#dw-topbar .dw-topbar-bd:after{content:"";display:table;line-height:0}#dw-topbar .dw-topbar-bd:after{clear:both}#dw-topbar .dw-topbar-logo,#dw-topbar .dw-topbar-homepage,#dw-topbar .dw-topbar-link,#dw-topbar .dw-topbar-nav,#dw-topbar .dw-topbar-login,#dw-topbar .dw-topbar-register,#dw-topbar .dw-topbar-username,#dw-topbar .dw-topbar-yuanbao,#dw-topbar .dw-topbar-logout,#dw-topbar .dw-topbar-download{height:36px;line-height:36px}#dw-topbar .dw-topbar-login,#dw-topbar .dw-topbar-register,#dw-topbar .dw-topbar-username,#dw-topbar .dw-topbar-yuanbao,#dw-topbar .dw-topbar-logout{margin-right:10px}#dw-topbar .dw-topbar-username{margin-right:20px}#dw-topbar .dw-topbar-yuanbao{margin-right:6px}#dw-topbar .dw-topbar-logout{display:none}#dw-topbar .dw-topbar-nav-bd{display:none}#dw-topbar .dw-topbar-logo{width:100px;height:25px;margin-top:5px;margin-right:30px;background:url(http://assets.dwstatic.com/project/topbar/img/logo.png) no-repeat 0 0;text-indent:100%;white-space:nowrap;overflow:hidden}#dw-topbar .dw-topbar-link,#dw-topbar .dw-topbar-homepage{margin-right:10px;vertical-align:middle}#dw-topbar .dw-topbar-link:hover,#dw-topbar .dw-topbar-homepage:hover{color:#e50450}#dw-topbar .dw-topbar-link{margin-right:20px}#dw-topbar .dw-topbar-nav{width:78px;position:relative;margin:0 10px 0 0}#dw-topbar .dw-topbar-nav .dw-topbar-title{display:block;width:65px;height:36px;line-height:36px;padding:0 1px 0 12px;position:relative;z-index:100;cursor:pointer;margin:0!important}#dw-topbar .dw-topbar-nav .dw-topbar-title i{display:block;width:7px;height:4px;overflow:hidden;background:url(http://assets.dwstatic.com/project/topbar/img/icon_arrow.png) no-repeat 0 0;position:absolute;left:63px;top:17px;transition:all 0.3s linear}#dw-topbar .dw-topbar-nav .dw-topbar-nav-bd{position:absolute;z-index:99;left:0;top:35px;border:1px solid #bababa;background-color:#FFF}#dw-topbar .dw-topbar-nav .dw-topbar-nav-bd table{width:100%}#dw-topbar .dw-topbar-nav .dw-topbar-nav-bd td{vertical-align:top}#dw-topbar .dw-topbar-nav .dw-topbar-nav-bd div{border-right:1px solid #EEE;padding:8px 14px}#dw-topbar .dw-topbar-nav .dw-topbar-nav-bd div.last-child{border-right:0 none}#dw-topbar .dw-topbar-nav .dw-topbar-nav-bd h3{height:24px;line-height:24px;font-weight:700;white-space:nowrap;color:#336596}#dw-topbar .dw-topbar-nav .dw-topbar-nav-bd a{height:24px;line-height:24px;display:block;overflow:hidden;white-space:nowrap}#dw-topbar .dw-topbar-nav .dw-topbar-nav-bd a:hover{color:#e20451;text-decoration:underline}#dw-topbar .dw-topbar-nav.dw-topbar-hover .dw-topbar-title{padding:0 0 0 11px;background-color:#FFF;border-left:1px solid #bababa;border-right:1px solid #bababa}#dw-topbar .dw-topbar-nav.dw-topbar-hover .dw-topbar-title i{-webkit-transform:rotate(180deg);-ms-transform:rotate(180deg);transform:rotate(180deg);zoom:1}#dw-topbar .dw-topbar-nav.dw-topbar-hover .dw-topbar-nav-bd{display:block}#dw-topbar .dw-topbar-userinfo form{float:left}#dw-topbar .dw-topbar-userinfo .dw-topbar-login{width:58px;height:20px;line-height:20px;text-align:center;margin-top:7px;border:1px solid #c1dd99;color:#66aa00;background-color:#f0f9ea}#dw-topbar .dw-topbar-userinfo .dw-topbar-login:hover{background-color:#f8fff3;text-decoration:none}#dw-topbar .dw-topbar-userinfo .dw-topbar-username{display:none;font-weight:700;color:#e50452}#dw-topbar .dw-topbar-userinfo .dw-topbar-username img{width:24px;height:24px;float:left;margin-right:5px;margin-top:6px}#dw-topbar .dw-topbar-userinfo .dw-topbar-username:hover{text-decoration:none;cursor:default}#dw-topbar .dw-topbar-userinfo .dw-topbar-nickname:hover{text-decoration:underline;cursor:pointer}#dw-topbar .dw-topbar-userinfo .dw-topbar-yuanbao{display:none}#dw-topbar .dw-topbar-userinfo .dw-topbar-yuanbao i{font-weight:700;color:#ff6600}#dw-topbar .dw-topbar-userinfo .dw-topbar-yuanbao:hover{color:#e50450}#dw-topbar .dw-topbar-userinfo .dw-topbar-yuanbao:hover i{color:#e50450}#dw-topbar .dw-topbar-userinfo .dw-topbar-download{width:68px;height:22px;overflow:hidden;line-height:22px;padding-left:32px;margin-top:6px;background:url(http://assets.dwstatic.com/project/topbar/img/bg_yy.png) no-repeat 0 0;color:#254a77}#dw-topbar .dw-topbar-userinfo .dw-topbar-download:hover{text-decoration:none;background-position:0 -22px;color:#936622}#udbsdk_cookieFrm iframe {width: 0; height: 0; overflow: hidden;}';

	var dynamicStyle = Util.createStyleSheet(CSS_TEXT);
	function addCSS(cssText) {
		if (document.createStyleSheet) {
			dynamicStyle.cssText += cssText;
		} else {
			dynamicStyle.appendChild(document.createTextNode(cssText));
		}
	}

	var navDom = {},
		rootEl = navDom.el = document.createElement("div");

	rootEl.id = "dw-topbar";
	rootEl.innerHTML = '<div class="dw-topbar-bd"><a href="http://www.duowan.com" class="dw-topbar-logo"><strong>多玩游戏网</strong></a><a href="http://www.duowan.com" class="dw-topbar-homepage">首页</a><div class="dw-topbar-nav" data-dom="gnav"><em class="dw-topbar-title">全站导航<i></i></em><div class="dw-topbar-nav-bd"></div></div><a href="http://www.5253.com/?daohang" class="dw-topbar-link">5253手游网</a><div class="dw-topbar-userinfo"><form action="https://udb.duowan.com/login.jsp" method="post" target="_self" data-dom="loginform"><a href="#" class="dw-topbar-login" data-dom="login" target="_self">安全登录</a><a href="https://udb.duowan.com/register.do" class="dw-topbar-register" data-dom="reglink">新用户注册</a></form><a href="javascript:void(0)" class="dw-topbar-username" data-dom="nickname" target="_self"></a><a href="#" class="dw-topbar-logout" data-dom="logout">退出</a><a href="http://www.yy.com/s/download.html" class="dw-topbar-download" data-stat="oper:yy-download">YY语音下载</a></div></div>';
	hashElements(rootEl, navDom);
	document.body.insertBefore(rootEl, document.body.firstChild);

	if (document.domain.toLowerCase().indexOf("sc2.com") > -1) {
		navDom.loginform.action = "https://udb.sc2.com.cn/login.jsp";
	//	navDom.reglink.href = "https://udb.sc2.com.cn/register.do";
	}

	function initUDB() {
		Util.getScript("http://assets.dwstatic.com/common/js/dwudbproxy.js", function() {

			username = dwUDBProxy.getCookie('username');
				pwd = dwUDBProxy.getCookie("password");

			if ( dwUDBProxy.isLogin() ) {
				navDom.nickname.style.display = "block";
				navDom.logout.style.display = "block";
				navDom.login.style.display = "none";
				navDom.reglink.style.display = "none";
				navDom.nickname.innerHTML = username;
				navDom.nickname.title = username;
			}
			
			Event.attach(navDom.login, "click", function(e) {
				Event.preventDefault(e);
				dwUDBProxy.login(''); //为空，登录成功后则跳转到当前页面
			});
			Event.attach(navDom.logout, "click", function(e) {
				Event.preventDefault(e);
				dwUDBProxy.logout('');  //为空，退出成功后则跳转到当前页面
			});
			
			// jquery cookie
			// !function(a){"function"==typeof define&&define.amd?define(["jquery"],a):"object"==typeof exports?a(require("jquery")):a(jQuery)}(function(a){function b(a){return h.raw?a:encodeURIComponent(a)}function c(a){return h.raw?a:decodeURIComponent(a)}function d(a){return b(h.json?JSON.stringify(a):String(a))}function e(a){0===a.indexOf('"')&&(a=a.slice(1,-1).replace(/\\"/g,'"').replace(/\\\\/g,"\\"));try{return a=decodeURIComponent(a.replace(g," ")),h.json?JSON.parse(a):a}catch(b){}}function f(b,c){var d=h.raw?b:e(b);return a.isFunction(c)?c(d):d}var g=/\+/g,h=a.cookie=function(e,g,i){if(void 0!==g&&!a.isFunction(g)){if(i=a.extend({},h.defaults,i),"number"==typeof i.expires){var j=i.expires,k=i.expires=new Date;k.setTime(+k+864e5*j)}return document.cookie=[b(e),"=",d(g),i.expires?"; expires="+i.expires.toUTCString():"",i.path?"; path="+i.path:"",i.domain?"; domain="+i.domain:"",i.secure?"; secure":""].join("")}for(var l=e?void 0:{},m=document.cookie?document.cookie.split("; "):[],n=0,o=m.length;o>n;n++){var p=m[n].split("="),q=c(p.shift()),r=p.join("=");if(e&&e===q){l=f(r,g);break}e||void 0===(r=f(r))||(l[q]=r)}return l};h.defaults={},a.removeCookie=function(b,c){return void 0===a.cookie(b)?!1:(a.cookie(b,"",a.extend({},c,{expires:-1})),!a.cookie(b))}});
			
			
			// 视频订阅通知
			// var videoSubNotice = {
			// 	_subscribe: jQuery(".dw-topbar-subscribe"),
				
			// 	_dropMenu: function(dataMap, callType, subCode){
			// 		var _this = this;
			// 		var hadLoad = true;
			// 		var defaultPic = "http://assets.dwstatic.com/common/img/blank.png";
			// 		var dataArr = [[],[],[]];
			// 		var subscribeBd = jQuery(".dw-topbar-subscribe__bd");
			// 		_this._subscribe.hover(function(){
			// 			jQuery(this).addClass("dw-topbar-subscribe--hover");
						
			// 			if (hadLoad) {
			// 				jQuery.each(dataMap, function(key, value){
		 //                    	dataArr[0].push(this.title);
		 //                    	dataArr[1].push(this.url);
		 //                    	if (!this.pictureurl) {
		 //                    		this.pictureurl = defaultPic;
		 //                    	} 
		 //                    	dataArr[2].push(this.pictureurl);
		 //                    })
							
			// 				setTimeout(function(){
			// 					subscribeBd.html('<p class="dw-topbar-subscribe__tips is-hidden"><i class="dw-topbar-subscribe__info"></i>您还没有任何订阅哦</p><h3 class="dw-topbar-subscribe__tit">新番订阅</h3><ul class="dw-topbar-subscribeFigure"><li class="dw-topbar-subscribeFigure__item"><a href="'+ dataArr[1][0] +'" class="dw-topbar-subscribeFigure__bd" title="'+ dataArr[0][0] +'" target="_blank"><img src="'+ dataArr[2][0] +'" alt="'+ dataArr[0][0] +'" class="dw-topbar-subscribeFigure__img" /><span class="dw-topbar-subscribeFigure__mask">'+ dataArr[0][0] +'</span></a></li><li class="dw-topbar-subscribeFigure__item"><a href="'+ dataArr[1][1] +'" class="dw-topbar-subscribeFigure__bd" title="'+ dataArr[0][1] +'" target="_blank"><img src="'+ dataArr[2][1] +'" alt="'+ dataArr[0][1] +'" class="dw-topbar-subscribeFigure__img" /><span class="dw-topbar-subscribeFigure__mask">'+ dataArr[0][1] +'</span></a></li></ul><ul class="dw-topbar-subscribeText"><li class="dw-topbar-subscribeText__item"><a href="'+ dataArr[1][2] +'" target="_blank"><i class="dw-topbar-subscribeText__dot"></i>'+ dataArr[0][2] +'</a></li><li class="dw-topbar-subscribeText__item"><a href="'+ dataArr[1][3] +'" target="_blank"><i class="dw-topbar-subscribeText__dot"></i>'+ dataArr[0][3] +'</a></li><li class="dw-topbar-subscribeText__item"><a href="'+ dataArr[1][4] +'" target="_blank"><i class="dw-topbar-subscribeText__dot"></i>'+ dataArr[0][4] +'</a></li><li class="dw-topbar-subscribeText__item"><a href="'+ dataArr[1][5] +'" target="_blank"><i class="dw-topbar-subscribeText__dot"></i>'+ dataArr[0][5] +'</a></li></ul>').promise().done(function(){
									
			// 						// 订阅没有更新
			// 						if (callType === 1) {
			// 							subscribeBd.find(".dw-topbar-subscribe__tips").removeClass("is-hidden").html('<i class="dw-topbar-subscribe__info"></i>您的订阅没有更新哦');
			// 							subscribeBd.find(".dw-topbar-subscribe__tit").text("新番推荐");
			// 						}
									
			// 						// 没有任何订阅
			// 						if (subCode === -1) {
			// 							subscribeBd.find(".dw-topbar-subscribe__tips").removeClass("is-hidden").html('<i class="dw-topbar-subscribe__info"></i>您还没有任何订阅哦');
			// 						}
									
			// 					});
								
			// 					// 取消未读标记并设置cookie
			// 					if (jQuery.cookie("newSubscribeNotice") === "isNotice" ) {
			// 						$(".dw-topbar-subscribe__hd").removeClass("is-notice");
			// 						jQuery.cookie("newSubscribeNotice", "hadReaded", {
			// 			                expires: 1,
			// 			                path: '/',
			// 							domain: 'duowan.com'
			// 			            });
			// 					}
									
			// 					hadLoad = false;
			// 				}, 100);
							
			// 			}
			// 		}, function(){
			// 			jQuery(this).removeClass("dw-topbar-subscribe--hover");
			// 		});
			// 	},
				
			// 	_getNewSub: function(){
			// 		var _this = this;
			// 		var getNewJSON = jQuery.ajax({
	  //                   type: "post",
	  //                   timeout: 5000,
	  //                   url: "http://huodong.duowan.com/videoSubscribe?r=subscribe/checksubsnew&time_ago=0",
	  //                   dataType: "jsonp",
	  //                   jsonpCallback: "checksubsnew" + new Date().getTime(),
	  //                   success: function(callData) {
	  //                       var status = callData.code;
	  //                       var dataMap = callData.data.list;
	  //                       var callType = callData.data.dataType;
	  //                       var isSubCode = 0;
	                        
	  //                       // 订阅有更新
	  //                       if (callType === 2) {
			// 					// 设置未读标记并设置cookie
	  //                       	if (!jQuery.cookie("newSubscribeNotice")) {
	  //                       		jQuery.cookie("newSubscribeNotice", "isNotice", {
			// 							expires: 1,
			// 							path: '/',
			// 							domain: 'duowan.com'
			// 						});
	  //                       	}
	  //                       	if (jQuery.cookie("newSubscribeNotice") ==="isNotice") {
			// 			            $(".dw-topbar-subscribe__hd").addClass("is-notice");
			// 			        }
	  //                       }
	                    
	  //                       jQuery.ajax({
			//                     type: "get",
			//                     timeout: 5000,
			//                     url: "http://huodong.duowan.com/videoSubscribe?r=subscribe/usersubs",
			//                     dataType: "jsonp",
			//                     jsonpCallback: "usersubs" + new Date().getTime(),
			//                     success: function(userSubsData) {
			//                         isSubCode = userSubsData.code;
			//                     },
			//                     complete: function(){
			//                     	_this._dropMenu(dataMap, callType, isSubCode);
			//                     },
			//                     error:function(XHR, textStatus, errorThrown){ 
			//                     }
			//                 });
			                
	  //                   },
	  //                   error:function(jqXHR, textStatus, errorThrown){ 
	  //                       // getNewJSON.abort();
	  //                       jQuery('.dw-topbar-subscribe').hide();
	  //                   }
	  //               });
			// 	},
				
			// 	_init: function(){
			// 		this._getNewSub();
			// 	}
			// };
			// videoSubNotice._init();
			
		});
	}

	if (window.jQuery) {
		jQuery(initUDB);
	} else {
		Util.getScript("http://assets.dwstatic.com/b=common/js&f=jquery-1.9.1.min.js,jquery-migrate-1.2.1.min.js", function() {
			var JQ = jQuery.noConflict(true);
			if (!window.jQuery) {
				window.jQuery = JQ;
				window.$ = JQ;
			}
			
			jQuery(initUDB);
		});
	}


	function NavMenu(el, requestUrl) {
		var dom = this.dom = {};
		dom.el = el;
		var lastRequestTime, _this = this, delayTimer, delay = 100;
		Event.mouseenter(el, function() {
			clearTimeout(delayTimer);
			delayTimer = setTimeout(function() {
				if (!_this._rendered) {
					var time = new Date().getTime();
					if (lastRequestTime == null || time - lastRequestTime > 1000) {
						lastRequestTime = time;
						Util.getScript(requestUrl);
					}
				}
				_this._hovering = true;
				_this.show();
			}, delay);
		});
		Event.mouseleave(el, function() {
			clearTimeout(delayTimer);
			delayTimer = setTimeout(function() {
				_this._hovering = false;
				_this.hide();
			}, delay);
		});
	}
	NavMenu.prototype = {
		_init: function(html, css) {
			if (this._inited) return;
			this._inited = true;
			var dom = this.dom,
			popup = document.createElement("div");
			popup.className = "dw-topbar-nav-bd";
			//popup.innerHTML = '<div class="pop-mc" data-dom="popc"></div>';
			hashElements(popup, dom);
			//popup.style.display = "none";
			dom.el.appendChild(popup);
			dom.popup = popup;
		},

		render: function(content, css) {
			this._init();
			if (!this._rendered && css) {
				addCSS(css);
			}
			var dom = this.dom;

			if (typeof content == "string") {
				dom.popup.innerHTML = content;
			} else {
				dom.popup.innerHTML = "";
				dom.popup.appendChild(content);
			}
			this._rendered = true;

			if (browser.msie || browser.opera) {
				var popup = this.dom.popup;
				popup.style.visibility = "hidden";
				this.show();
				popup.style.width = this.dom.popup.firstChild.offsetWidth + 28 + "px";
				if (!this._hovering) {
					this.hide();
				}
				popup.style.visibility = "";
			} else if (this._hovering) {
				this.show();
			}
		},

		show: function() {
			if (!this._rendered) return;
			Dom.addClass(this.dom.el, "dw-topbar-hover");
		},

		hide: function() {
			if (!this._rendered) return;
			Dom.removeClass(this.dom.el, "dw-topbar-hover");
		}
	};

	var Navbar = window.Navbar = {
		dom: navDom
	};
	// Navbar_PDataHost = window.Navbar_PDataHost || "http://navbar.duowan.com/";
	//Navbar_NewsDataUrl = window.Navbar_NewsDataUrl || "http://www.duowan.com/public/s/i/navbar/nav-news.js";

	Navbar.gNav = new NavMenu(navDom.gnav, window.Navbar_GDataUrl || "http://www.duowan.com/s/1305_navbar/js/navbar_link.js");

})();