(function() {

    "use strict";

var Util = {
    _regExpTrim: /^(\s|\u00A0)+|(\s|\u00A0)+$/g,
    trim: function(text) {
        return (text || "").replace(Util._regExpTrim, "");
    },
    isFunction: function(obj) {
        return Object.prototype.toString.call(obj) === "[object Function]";
    },
    createStyleSheet: function(cssText) {
        var stylesheet;
        if (document.createStyleSheet) {
            stylesheet = document.createStyleSheet();
            stylesheet.cssText = cssText;
        } else {
            stylesheet = document.createElement("style");
            stylesheet.appendChild(document.createTextNode(cssText));
            document.getElementsByTagName("head")[0].appendChild(stylesheet);
        }
        return stylesheet;
    },
    getScript: function(url, callback) {
        var head = document.getElementsByTagName("head")[0] || document.documentElement;
        var script = document.createElement("script");
        script.type = "text/javascript";
        script.async = true;
        script.charset = "utf-8";
        script.src = url;
        script.onload = script.onreadystatechange = function() {
            if (!script.readyState || /loaded|complete/.test(script.readyState)) {
                if (Util.isFunction(callback)) {
                    callback();
                }
                script.onload = script.onreadystatechange = null;
                if (script.parentNode) {
                    script.parentNode.removeChild(script);
                }
            }
        };
        head.insertBefore(script, null);
    }
};

/*!
multiline
Multiline strings in JavaScript
https://github.com/sindresorhus/multiline
by Sindre Sorhus
MIT License
*/
var reCommentContents = /\/\*!?(?:\@preserve)?[ \t]*(?:\r\n|\n)([\s\S]*?)(?:\r\n|\n)[ \t]*\*\//;
var multiline = function (fn) {
    if (typeof fn !== 'function') {
        throw new TypeError('Expected a function');
    }
    var match = reCommentContents.exec(fn.toString());
    if (!match) {
        throw new TypeError('Multiline comment missing.');
    }
    return match[1];
};

var CSS_TEXT = multiline(function(){/*!@preserve
#footer{clear:both;width:100%;margin:0 auto;padding:15px 0;}
#footer div,#footer p{margin:8px auto;text-align:center;line-height:1;}
#footer a{margin:0 4px;}
#footer a b{font-weight:700;color:#F40;}
.footerApprove{line-height: 1.5!important;font-size:0}
.footerApprove__link{position:relative;display:inline-block;*display:inline;*zoom:1;width:64px;height:36px;margin:0 10px!important;padding-left:40px;font-size:12px;text-align:left;cursor:pointer}
.footerApprove__link i{position:absolute;left:0;top:0;width:36px;height:36px;background-image:url(http://assets.dwstatic.com/www/1.2.1/img/approve-icons.gif?20150213);background-repeat:no-repeat;overflow:hidden}
.footerApprove__link.is-short{width:52px}
.footerApprove__315{width:90px}
.footerApprove__315 i{width:130px;margin-top:4px}
.footerApprove__icon2{background-position:-42px 0}
.footerApprove__icon3{background-position:-84px 0}
.footerApprove__icon4{background-position:-214px 2px}
.footerApprove__icon5{background-position:-256px 0}
*/console.log});

var FOOT_HTML = multiline(function(){/*!@preserve
<div id="footer">
    <div class="foot-nav">
        <a href="http://www.huanju.cn/s/introduction.html">关于欢聚</a>|<a href="http://hr.yy.com/">欢聚招聘</a>|<a href="http://www.huanju.cn/s/contact.html">联系欢聚</a>|<a href="http://www.huanju.cn/s/links.html">友情链接</a>|<a href="http://www.huanju.cn/s/contact.html">广告热线：020-29162026</a>|<a href="http://www.yy.com/go.html#10">客服频道：<b>10</b></a>|<a href="http://kf.yy.com">YY客服中心</a>|<a href="http://www.huanju.cn/1207/m_205349693256.html">隐私权保护政策</a>|<a href="http://www.huanju.cn/1207/m_205353486825.html">版权保护投诉指引</a>|<a href="http://www.100.com">100教育</a>
    </div>
    <div class="copyright">
        <p>增值电信业务经营许可证<a href="http://assets.dwstatic.com/common/docs/B2-20050785.jpg">粤B2-20050785</a><a href="http://assets.dwstatic.com/common/docs/B2-20120129.jpg">B2-20120129</a>|<a href="http://assets.dwstatic.com/common/docs/1910441.jpg">视听许可证1910441号</a>|<a href="http://assets.dwstatic.com/common/docs/0605-096.jpg?1229">粤网文[2012]0605-096号</a>| 举报邮箱：dwkf@yy.com</p>
        <p><a href="http://www.miitbeian.gov.cn">粤ICP备09075143号</a>|<a href="http://www.miitbeian.gov.cn">京ICP备05047096号</a>|<a href="http://assets.dwstatic.com/common/docs/4401060100548.jpg">穗公网监备案证第4401060100548号</a>|<a href="http://www.gdca.gov.cn/">广东省通信管理局</a>|<a href="http://assets.dwstatic.com/common/docs/038.jpg">互联网出版许可证</a>|<a href="http://assets.dwstatic.com/common/docs/01022.jpg">节目制作经营许可证</a></p>
        <p>&copy; 2005-2015 Duowan.com 版权所有</p>
    </div>
    <div class="footerApprove"><a class="footerApprove__link" href="http://guangzhou.cyberpolice.cn/netalarm/netalarm/wangjian_index.jsp"><i class="footerApprove__icon1"></i>广州网络警察报警平台</a><a class="footerApprove__link" href="http://210.76.65.188/newwebsite/main.jsp?id=4401&amp;adir=&amp;wy=1"><i class="footerApprove__icon2"></i>公共信息安全网络监察</a><a class="footerApprove__link is-short" href="http://netadreg.gzaic.gov.cn/ntmm/WebSear/WebLogoPub.aspx?logo=440106106022005041100016"><i class="footerApprove__icon1"></i>工商网监红盾认证</a><a class="footerApprove__link footerApprove__315" href="http://315web.duowan.com/index.jsp"><i class="footerApprove__icon3"></i></a><a class="footerApprove__link is-short" href="http://www.net.china.com.cn/txt/2015-01/20/content_7622927.htm"><i class="footerApprove__icon5"></i>网络敲诈有偿删帖</a><a class="footerApprove__link" href="http://www.12377.cn/"><i class="footerApprove__icon4"></i>违法不良信息举报中心</a>
    </div>
</div>
*/console.log});

Util.createStyleSheet(CSS_TEXT);
document.write(FOOT_HTML);

if (!window.jQuery) {
    Util.getScript("http://assets.dwstatic.com/b=common/js&f=jquery-1.11.1.min.js,jquery-migrate-1.2.1.min.js&20141230");
}

// 全站弹框
var s = document.getElementById("dw-footer-without-gem");
// var mobi =/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);
var mobi = (/Android|iPhone|iPad|iPod|BlackBerry/i).test(navigator.userAgent || navigator.vendor || window.opera);
if (!s && !mobi) document.writeln('<script src="http://assets.dwstatic.com/amkit/entry.js" data-entry="p/livetip/1.1.0/main"><\/script>');
s = null;


// 适配iOS视频
if(mobi) {
    var embeds  = jQuery('embed[src*=swf]');
    var youkuPattern = /\/sid\/([\w]+)[\W]/;
    var tudouPattern = /\/v\/([^\/]+)\//;
    var sohuPattern  = /id=([\d]+)[\D]/i;
    jQuery.each(embeds, function(i, v){
        var _U = jQuery(embeds[i]).attr('src');
        var _W = jQuery(embeds[i]).attr('width');
        var _H = jQuery(embeds[i]).attr('height');
        if(_U.match(/youku/)){
            var vid = _U.match(youkuPattern)[1];
            if(vid != null){
                jQuery(embeds[i]).replaceWith('<iframe width='+_W+' height='+_H+' src="http://player.youku.com/embed/'+vid+'" frameborder=0 allowfullscreen></iframe>');
            };
        }else if(_U.match(/tudou/)){
            var vid = _U.match(tudouPattern)[1];
            if(vid != null){
                jQuery(embeds[i]).replaceWith('<iframe width="'+_W+'" height="'+_H+'" frameborder="0" src="http://www.tudou.com/programs/view/html5embed.action?code='+vid+'"></iframe>');
            };
        }else if(_U.match(/sohu/)){
            var vid = _U.match(sohuPattern)[1];
            if(vid != null){
                jQuery(embeds[i]).replaceWith('<video width="'+_W+'" height="'+_H+'" x-webkit-airplay="allow" preload controls src="http://my.tv.sohu.com/ipad/'+vid+'.m3u8"></video>');
            };
        };
    });
};
document.writeln('<script src="http://assets.dwstatic.com/amkit/entry.js" data-entry="p/footer/main"><\/script>');
document.writeln('<script src="http://www.duowan.com/duowan.js"><\/script>');
document.writeln('<script src="http://www.duowan.com/public/s/market_count.js"><\/script>');
document.writeln('<script src="http://www.duowan.com/s/statistics.js"><\/script>');


})();
